@@ -1,6 +1,6 @@
 package MySQL::Sandbox::Recipes;
 
-our $VERSION="3.0.66";
+our $VERSION="3.1.00";
 
 1;
 __END__
@@ -670,25 +670,26 @@ MySQL Sandbox 3.0.32 and later include a script that lets you deploy a sandbox q
 
 =head1 COPYRIGHT
 
-Version 3.0
+Version 3.1
 
-Copyright (C) 2006-2013 Giuseppe Maxia
+Copyright (C) 2006-2015 Giuseppe Maxia
 
-Home Page  http://launchpad.net/mysql-sandbox/
+Home Page  http://github.com/datacharmer
 
 =head1 LEGAL NOTICE
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; version 2 of the License.
+   Copyright 2006-2015 Giuseppe Maxia
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
 
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
-USA
 
